package com.ruoyi.ems.service;

import com.ruoyi.ems.domain.OpAlarm;

import java.util.List;
import java.util.Map;

/**
 * 能源设施告警Service接口
 *
 * @author ruoyi
 * @date 2024-08-26
 */
public interface IOpAlarmService {
    /**
     * 查询能源设施告警
     *
     * @param id 能源设施告警主键
     * @return 能源设施告警
     */
    OpAlarm selectOpAlarmById(Long id);

    /**
     * 查询能源设施告警列表
     *
     * @param opAlarm 能源设施告警
     * @return 能源设施告警集合
     */
    List<OpAlarm> selectOpAlarmList(OpAlarm opAlarm);

    /**
     * 新增能源设施告警
     *
     * @param opAlarm 能源设施告警
     * @return 结果
     */
    int insertOpAlarm(OpAlarm opAlarm);

    /**
     * 修改能源设施告警
     *
     * @param opAlarm 能源设施告警
     * @return 结果
     */
    int updateOpAlarm(OpAlarm opAlarm);

    /**
     * 批量删除能源设施告警
     *
     * @param ids 需要删除的能源设施告警主键集合
     * @return 结果
     */
    int deleteOpAlarmByIds(Long[] ids);

    /**
     * 删除能源设施告警信息
     *
     * @param id 能源设施告警主键
     * @return 结果
     */
    int deleteOpAlarmById(Long id);

    List<Map<String, Object>> qryAlarmTypeIndex(String areaCode, String startTime, String endTime);

    List<Map<String, Object>> qryAlarmTypeIndexByDate(OpAlarm params);

    List<Map<String, Object>> qryAlarmTypeIndexDay(String areaCode);

    List<Map<String, Object>> qryAlarmTypeIndexMonth(String areaCode);

    List<Map<String, Object>> qryAlarmTypeIndexYear(String areaCode);

    List<Map<String, Object>> qrySubSysIndexDay(String areaCode);

    List<Map<String, Object>> qrySubSysIndexMonth(String areaCode);

    List<Map<String, Object>> qrySubSysIndexYear(String areaCode);

    Map<String, Object> cntHandledAlarmByDate(OpAlarm admOpAlarm);
}
