package com.ruoyi.ems.controller;

import java.util.List;

import javax.servlet.http.HttpServletResponse;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;

import com.huashe.common.domain.AjaxResult;
import com.ruoyi.common.core.utils.poi.ExcelUtil;
import com.ruoyi.common.core.web.controller.BaseController;
import com.ruoyi.common.core.web.page.TableDataInfo;
import com.ruoyi.common.log.annotation.Log;
import com.ruoyi.common.log.enums.BusinessType;
import com.ruoyi.common.security.annotation.RequiresPermissions;
import com.ruoyi.ems.domain.OpAlarm;
import com.ruoyi.ems.service.IOpAlarmService;

import io.swagger.annotations.Api;

/**
 * 能源设施告警Controller
 *
 * @author ruoyi
 * @date 2024-08-26
 */
@RestController
@RequestMapping("/alarm-info")
@Api(value = "AdmOpAlarmController", description = "能源设施告警")
public class OpAlarmController extends BaseController {
    @Autowired
    private IOpAlarmService opAlarmService;

    /**
     * 查询能源设施告警列表
     */
    @RequiresPermissions("ems:alarm-info:list")
    @GetMapping("/list")
    public TableDataInfo list(OpAlarm admOpAlarm) {
        startPage();
        List<OpAlarm> list = opAlarmService.selectOpAlarmList(admOpAlarm);
        return getDataTable(list);
    }

    /**
     * 导出能源设施告警列表
     */
    @RequiresPermissions("ems:alarm-info:export")
    @Log(title = "能源设施告警", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, OpAlarm opAlarm) {
        List<OpAlarm> list = opAlarmService.selectOpAlarmList(opAlarm);
        ExcelUtil<OpAlarm> util = new ExcelUtil<OpAlarm>(OpAlarm.class);
        util.exportExcel(response, list, "能源设施告警数据");
    }

    /**
     * 获取能源设施告警详细信息
     */
    @RequiresPermissions("ems:alarm-info:query")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id) {
        return success(opAlarmService.selectOpAlarmById(id));
    }

    /**
     * 新增能源设施告警
     */
    @RequiresPermissions("ems:alarm-info:add")
    @Log(title = "能源设施告警", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody OpAlarm opAlarm) {
        return toAjax(opAlarmService.insertOpAlarm(opAlarm));
    }

    /**
     * 修改能源设施告警
     */
    @RequiresPermissions("ems:alarm-info:edit")
    @Log(title = "能源设施告警", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody OpAlarm opAlarm) {
        return toAjax(opAlarmService.updateOpAlarm(opAlarm));
    }

    /**
     * 删除能源设施告警
     */
    @RequiresPermissions("ems:alarm-info:remove")
    @Log(title = "能源设施告警", businessType = BusinessType.DELETE)
    @DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids) {
        return toAjax(opAlarmService.deleteOpAlarmByIds(ids));
    }

    @GetMapping("/alarm/type/index")
    @RequiresPermissions("ems:alarm-info:query")
    public AjaxResult qryAlarmTypeIndex(@RequestParam(name = "areaCode", required = false) String areaCode,
        @RequestParam("startRecTime") String startTime, @RequestParam("endRecTime") String endTime) {
        return success(opAlarmService.qryAlarmTypeIndex(areaCode, startTime, endTime));
    }

    @GetMapping("/alarm/type/index/day")
    @RequiresPermissions("ems:alarm-info:query")
    public AjaxResult qryAlarmTypeIndexDay(@RequestParam(name = "areaCode", required = false) String areaCode) {
        return success(opAlarmService.qryAlarmTypeIndexDay(areaCode));
    }

    @GetMapping("/alarm/type/index/month")
    @RequiresPermissions("ems:alarm-info:query")
    public AjaxResult qryAlarmTypeIndexMonth(@RequestParam(name = "areaCode", required = false) String areaCode) {
        return success(opAlarmService.qryAlarmTypeIndexMonth(areaCode));
    }

    @GetMapping("/alarm/type/index/year")
    @RequiresPermissions("ems:alarm-info:query")
    public AjaxResult qryAlarmTypeIndexYear(@RequestParam(name = "areaCode", required = false) String areaCode) {
        return success(opAlarmService.qryAlarmTypeIndexYear(areaCode));
    }

    @GetMapping("/subsys/index/day")
    @RequiresPermissions("ems:alarm-info:query")
    public AjaxResult qrySubSysIndexDay(@RequestParam(name = "areaCode", required = false) String areaCode) {
        return success(opAlarmService.qrySubSysIndexDay(areaCode));
    }

    @GetMapping("/subsys/index/month")
    @RequiresPermissions("ems:alarm-info:query")
    public AjaxResult qrySubSysIndexMonth(@RequestParam(name = "areaCode", required = false) String areaCode) {
        return success(opAlarmService.qrySubSysIndexMonth(areaCode));
    }

    @GetMapping("/subsys/index/year")
    @RequiresPermissions("ems:alarm-info:query")
    public AjaxResult qrySubSysIndexYear(@RequestParam(name = "areaCode", required = false) String areaCode) {
        return success(opAlarmService.qrySubSysIndexYear(areaCode));
    }

    @GetMapping("/cnt/handled")
    public AjaxResult cntHandledAlarmByDate(OpAlarm opAlarm) {
        return success(opAlarmService.cntHandledAlarmByDate(opAlarm));
    }

    @GetMapping("/cnt/date/alarm/type")
    public AjaxResult qryAlarmTypeIndexByDate(OpAlarm opAlarm) {
        return success(opAlarmService.qryAlarmTypeIndexByDate(opAlarm));
    }

}
